==> qmmp-0.10.6.tar.bz2: qmmp-0.10.6/src/app/translations/qmmp_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>プレイリストをクリアしない</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>今の曲から再生を開始</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>今の曲で一時停止</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>再生中なら一時停止、一時停止しておれば再生</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>今の曲で終止</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>「ファイルを指定して即刻再生」ダイアログを表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>アプリケーションを終了</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>音量設定 (例: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Mute/Restore volume</source>
        <translation>消音/奏音</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Skip forward in playlist</source>
        <translation>プレイリストでの次の曲にスキップ</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Skip backwards in playlist</source>
        <translation>プレイリストで前の曲にスキップ</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Show/hide application</source>
        <translation>アプリケーションウィンドウを表示/非表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Show main window</source>
        <translation>メインウィンドウを表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Display Add File dialog</source>
        <translation>「ファイル追加」ダイアログを表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Display Add Directory dialog</source>
        <translation>「ディレクトリ追加」ダイアログを表示</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="93"/>
        <source>Unknown command</source>
        <translation>不明なコマンドです</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="342"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>使用法: qmmp [オプション] [ファイル名:複数可]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="343"/>
        <source>Options:</source>
        <translation>オプション:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="347"/>
        <source>Don&apos;t start the application</source>
        <translation>アプリケーションを始動しない</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="348"/>
        <source>Display this text and exit</source>
        <translation>このメッセージを表示して終了</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="349"/>
        <source>Print version number and exit</source>
        <translation>バージョン番号を表示して終了</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="350"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>名案, パッチ, バグ報告は forkotov02@hotmail.ru まで</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="353"/>
        <source>Command Line Help</source>
        <translation>コマンド行ヘルプ</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="366"/>
        <source>QMMP version: %1</source>
        <translation>QMMP のバージョン: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="367"/>
        <source>Compiled with Qt version: %1</source>
        <translation>コンパイルに使用した Qt のバージョン: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="368"/>
        <source>Using Qt version: %1</source>
        <translation>現在使用中の Qt のバージョン: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="371"/>
        <source>Qmmp Version</source>
        <translation>QMMP バージョン</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/app/translations/qmmp_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>プレイリストをクリアしない</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>今の曲から再生を開始</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>今の曲で一時停止</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>再生中なら一時停止、一時停止しておれば再生</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>今の曲で終止</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>「ファイルを指定して即刻再生」ダイアログを表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>アプリケーションを終了</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>音量設定 (例: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Print volume level</source>
        <translation>音量設定値を表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Mute/Restore volume</source>
        <translation>消音/奏音</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Print mute status</source>
        <translation>消音設定の有無を表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Skip forward in playlist</source>
        <translation>プレイリストでの次の曲にスキップ</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Skip backwards in playlist</source>
        <translation>プレイリストで前の曲にスキップ</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Show/hide application</source>
        <translation>アプリケーションウィンドウを表示/非表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Show main window</source>
        <translation>メインウィンドウを表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="86"/>
        <source>Display Add File dialog</source>
        <translation>「ファイル追加」ダイアログを表示</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="87"/>
        <source>Display Add Directory dialog</source>
        <translation>「ディレクトリ追加」ダイアログを表示</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="113"/>
        <source>Unknown command</source>
        <translation>不明なコマンドです</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="407"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>使用法: qmmp [オプション] [ファイル名:複数可]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="408"/>
        <source>Options:</source>
        <translation>オプション:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="414"/>
        <source>Start qmmp with the specified user interface</source>
        <translation>ユーザーインターフェイスを選んで起動する</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="415"/>
        <source>List all available user interfaces</source>
        <translation>利用可能なユーザーインターフェイス一覧</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="416"/>
        <source>Don&apos;t start the application</source>
        <translation>アプリケーションを始動しない</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="417"/>
        <source>Display this text and exit</source>
        <translation>このメッセージを表示して終了</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="418"/>
        <source>Print version number and exit</source>
        <translation>バージョン番号を表示して終了</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="420"/>
        <source>Home page: %1</source>
        <translation>ホームページ: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="421"/>
        <source>Development page: %1</source>
        <translation>開発者のページ: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="422"/>
        <source>Bug tracker: %1</source>
        <translation>バグトラッカー: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="135"/>
        <location filename="../qmmpstarter.cpp" line="427"/>
        <source>Command Line Help</source>
        <translation>コマンド行ヘルプ</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="440"/>
        <source>QMMP version: %1</source>
        <translation>QMMP のバージョン: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="441"/>
        <source>Compiled with Qt version: %1</source>
        <translation>コンパイルに使用した Qt のバージョン: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="442"/>
        <source>Using Qt version: %1</source>
        <translation>現在使用中の Qt のバージョン: %1</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="445"/>
        <source>Qmmp Version</source>
        <translation>QMMP バージョン</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="462"/>
        <source>User Interfaces</source>
        <translation>ユーザーインターフェイス</translation>
    </message>
</context>
</TS>
